@@ -182,6 +182,14 @@ static const MbimUuid uuid_ms_host_shutdown = {
     .e = { 0x27, 0xd7, 0xfb, 0x80, 0x95, 0x9c }
 };
 
+static const MbimUuid uuid_ms_sar = {
+    .a = { 0x68, 0x22, 0x3d, 0x04 },
+    .b = { 0x9f, 0x6c },
+    .c = { 0x4e, 0x0f },
+    .d = { 0x82, 0x2d },
+    .e = { 0x28, 0x44, 0x1f, 0xb7, 0x23, 0x40 }
+};
+
 static const MbimUuid uuid_proxy_control = {
     .a = { 0x83, 0x8c, 0xf7, 0xfb },
     .b = { 0x8d, 0x0d },
@@ -215,6 +223,14 @@ static const MbimUuid uuid_intel_firmware_update = {
     .e = { 0x3b, 0x3f, 0xd7, 0x6f, 0x56, 0x41 }
 };
 
+static const MbimUuid uuid_qdu = {
+    .a = { 0x64, 0x27, 0x01, 0x5f },
+    .b = { 0x57, 0x9d },
+    .c = { 0x48, 0xf5 },
+    .d = { 0x8c, 0x54 },
+    .e = { 0xf4, 0x3e, 0xd1, 0xe7, 0x6f, 0x83 }
+};
+
 static const MbimUuid uuid_ms_basic_connect_extensions = {
     .a = { 0x3d, 0x01, 0xdc, 0xc5 },
     .b = { 0xfe, 0xf5 },
@@ -223,6 +239,14 @@ static const MbimUuid uuid_ms_basic_connect_extensions = {
     .e = { 0xbe, 0xf7, 0x05, 0x8e, 0x9a, 0xaf }
 };
 
+static const MbimUuid uuid_ms_uicc_low_level_access = {
+    .a = { 0xc2, 0xf6, 0x58, 0x8e },
+    .b = { 0xf0, 0x37 },
+    .c = { 0x4b, 0xc9 },
+    .d = { 0x86, 0x65 },
+    .e = { 0xf4, 0xd4, 0x4b, 0xd0, 0x93, 0x67 }
+};
+
 static GList *mbim_custom_service_list = NULL;
 
 typedef struct {
@@ -336,16 +360,22 @@ mbim_uuid_from_service (MbimService service)
         return &uuid_ms_firmware_id;
     case MBIM_SERVICE_MS_HOST_SHUTDOWN:
         return &uuid_ms_host_shutdown;
+    case MBIM_SERVICE_MS_SAR:
+        return &uuid_ms_sar;
     case MBIM_SERVICE_PROXY_CONTROL:
         return &uuid_proxy_control;
     case MBIM_SERVICE_QMI:
         return &uuid_qmi;
     case MBIM_SERVICE_ATDS:
         return &uuid_atds;
+    case MBIM_SERVICE_QDU:
+        return &uuid_qdu;
     case MBIM_SERVICE_INTEL_FIRMWARE_UPDATE:
         return &uuid_intel_firmware_update;
     case MBIM_SERVICE_MS_BASIC_CONNECT_EXTENSIONS:
         return &uuid_ms_basic_connect_extensions;
+    case MBIM_SERVICE_MS_UICC_LOW_LEVEL_ACCESS:
+        return &uuid_ms_uicc_low_level_access;
     case MBIM_SERVICE_LAST:
         g_assert_not_reached ();
     default:
@@ -389,6 +419,9 @@ mbim_uuid_to_service (const MbimUuid *uuid)
     if (mbim_uuid_cmp (uuid, &uuid_ms_host_shutdown))
         return MBIM_SERVICE_MS_HOST_SHUTDOWN;
 
+    if (mbim_uuid_cmp (uuid, &uuid_ms_sar))
+        return MBIM_SERVICE_MS_SAR;
+
     if (mbim_uuid_cmp (uuid, &uuid_proxy_control))
         return MBIM_SERVICE_PROXY_CONTROL;
 
@@ -401,9 +434,15 @@ mbim_uuid_to_service (const MbimUuid *uuid)
     if (mbim_uuid_cmp (uuid, &uuid_intel_firmware_update))
         return MBIM_SERVICE_INTEL_FIRMWARE_UPDATE;
 
+    if (mbim_uuid_cmp (uuid, &uuid_qdu))
+        return MBIM_SERVICE_QDU;
+
     if (mbim_uuid_cmp (uuid, &uuid_ms_basic_connect_extensions))
         return MBIM_SERVICE_MS_BASIC_CONNECT_EXTENSIONS;
 
+    if (mbim_uuid_cmp (uuid, &uuid_ms_uicc_low_level_access))
+        return MBIM_SERVICE_MS_UICC_LOW_LEVEL_ACCESS;
+
     for (l = mbim_custom_service_list; l != NULL; l = l->next) {
         if (mbim_uuid_cmp (&((MbimCustomService *)l->data)->uuid, uuid))
             return ((MbimCustomService *)l->data)->service_id;
